@@ -394,7 +394,13 @@ def create_opentelemetry_tracer(
                 "tracing_opentelemetry_collector_endpoint_insecure", False
             ),
         )
-        ot_exporter = OTLPSpanExporter(endpoint=collector_endpoint, insecure=insecure)
+        headers = kwargs.get(
+            "collector_headers",
+            configuration.get("tracing_opentelemetry_collector_headers", None),
+        )
+        ot_exporter = OTLPSpanExporter(
+            endpoint=collector_endpoint, headers=headers, insecure=insecure
+        )
     elif exporter == "oltp-http":
         from opentelemetry.exporter.otlp.proto.http.trace_exporter import (
             OTLPSpanExporter,
@@ -406,13 +412,11 @@ def create_opentelemetry_tracer(
                 "tracing_opentelemetry_collector_endpoint", "http://localhost:4317"
             ),
         )
-        insecure = kwargs.get(
-            "collector_insecure",
-            configuration.get(
-                "tracing_opentelemetry_collector_endpoint_insecure", False
-            ),
+        headers = kwargs.get(
+            "collector_headers",
+            configuration.get("tracing_opentelemetry_collector_headers", None),
         )
-        ot_exporter = OTLPSpanExporter(endpoint=collector_endpoint, insecure=insecure)
+        ot_exporter = OTLPSpanExporter(endpoint=collector_endpoint, headers=headers)
 
     baggage = kwargs.get(
         "baggage_prefix", configuration.get("tracing_opentelemetry_baggage_prefix")
